@@ -1,59 +1,64 @@
-#define HCX_DO_RCASCAN			1
-#define HCX_RCASCAN_MAX			2
-#define HCX_RCASCAN_ORDER		3
-#define HCX_DO_TARGETSCAN		4
-#define HCX_DEAUTH_REASON_CODE		5
-#define HCX_DISABLE_DEAUTHENTICATION	6
-#define HCX_DISABLE_AP_ATTACKS		7
-#define HCX_STOP_AP_ATTACKS		8
-#define HCX_RESUME_AP_ATTACKS		9
-#define HCX_DISABLE_CLIENT_ATTACKS	10
-#define HCX_STOP_CLIENT_M2_ATTACKS	11
-#define HCX_SILENT			12
-#define HCX_GPS_DEVICE			13
-#define HCX_GPSD			14
-#define HCX_NMEA_NAME			15
-#define HCX_EAPOL_TIMEOUT		16
-#define HCX_ACTIVE_BEACON		17
-#define HCX_FLOOD_BEACON		18
-#define HCX_EXTAP_BEACON		19
-#define HCX_INFINITY			20
-#define HCX_FILTERLIST_AP		21
-#define HCX_FILTERLIST_CLIENT		22
-#define HCX_FILTERMODE			23
-#define HCX_BPFC			24
-#define HCX_WEAKCANDIDATE		25
-#define HCX_TOT				26
-#define HCX_REBOOT			27
-#define HCX_POWER_OFF			28
-#define HCX_GPIO_BUTTON			29
-#define HCX_GPIO_STATUSLED		30
-#define HCX_IP				31
-#define HCX_SERVER_PORT			32
-#define HCX_CLIENT_PORT			33
-#define HCX_CHECK_DRIVER		34
-#define HCX_CHECK_INJECTION		35
-#define HCX_ERROR_MAX			36
-#define HCX_STATUS			37
-#define HCX_BEACONPARAMS		38
-#define HCX_WPAENT			39
-#define HCX_EAPREQ			40
-#define HCX_EAPTUN			41
-#define HCX_EAP_SERVER_CERT		42
-#define HCX_EAP_SERVER_KEY		43
-#define HCX_EAPOL_EAP_TIMEOUT		44
-#define HCX_INTERFACE_NAME		'i'
-#define HCX_PCAPNG_NAME			'o'
-#define HCX_PACPNG_FRAMES		'f'
-#define HCX_CHANNEL			'c'
-#define HCX_SCANLIST			's'
-#define HCX_STAYTIME			't'
-#define HCX_SHOW_INTERFACES		'I'
-#define HCX_SHOW_CHANNELS		'C'
-#define HCX_SET_MONITORMODE		'm'
-#define HCX_HELP			'h'
-#define HCX_EXAMPLE			'x'
-#define HCX_VERSION			'v'
+#define HCX_DO_RCASCAN				1
+#define HCX_RCASCAN_MAX				2
+#define HCX_RCASCAN_ORDER			3
+#define HCX_DO_TARGETSCAN			4
+#define HCX_DEAUTH_REASON_CODE			5
+#define HCX_DISABLE_DEAUTHENTICATION		6
+#define HCX_DISABLE_AP_ATTACKS			7
+#define HCX_STOP_AP_ATTACKS			8
+#define HCX_RESUME_AP_ATTACKS			9
+#define HCX_DISABLE_CLIENT_ATTACKS		10
+#define HCX_STOP_CLIENT_M2_ATTACKS		11
+#define HCX_SILENT				12
+#define HCX_GPS_DEVICE				13
+#define HCX_GPSD				14
+#define HCX_NMEA_NAME				15
+#define HCX_EAPOL_TIMEOUT			16
+#define HCX_ACTIVE_BEACON			17
+#define HCX_FLOOD_BEACON			18
+#define HCX_EXTAP_BEACON			19
+#define HCX_EXTAP_WPAENTBEACON			20
+#define HCX_INFINITY				21
+#define HCX_FILTERLIST_AP			22
+#define HCX_FILTERLIST_CLIENT			23
+#define HCX_FILTERLIST_AP_VENDOR		24
+#define HCX_FILTERLIST_CLIENT_VENDOR		25
+#define HCX_FILTERMODE				26
+#define HCX_BPFC				27
+#define HCX_WEAKCANDIDATE			28
+#define HCX_TOT					29
+#define HCX_REBOOT				30
+#define HCX_POWER_OFF				31
+#define HCX_GPIO_BUTTON				32
+#define HCX_GPIO_STATUSLED			33
+#define HCX_GPIO_STATUSLED_FLASHINTERVAL	34
+#define HCX_IP					35
+#define HCX_SERVER_PORT				36
+#define HCX_CLIENT_PORT				37
+#define HCX_CHECK_DRIVER			38
+#define HCX_CHECK_INJECTION			39
+#define HCX_ERROR_MAX				40
+#define HCX_STATUS				41
+#define HCX_BEACONPARAMS			42
+#define HCX_WPAENT				43
+#define HCX_EAPREQ				44
+#define HCX_EAPREQ_FOLLOWNAK	45
+#define HCX_EAPTUN				46
+#define HCX_EAP_SERVER_CERT			47
+#define HCX_EAP_SERVER_KEY			48
+#define HCX_EAPOL_EAP_TIMEOUT			49
+#define HCX_INTERFACE_NAME			'i'
+#define HCX_PCAPNG_NAME				'o'
+#define HCX_PACPNG_FRAMES			'f'
+#define HCX_CHANNEL				'c'
+#define HCX_SCANLIST				's'
+#define HCX_STAYTIME				't'
+#define HCX_SHOW_INTERFACES			'I'
+#define HCX_SHOW_CHANNELS			'C'
+#define HCX_SET_MONITORMODE			'm'
+#define HCX_HELP				'h'
+#define HCX_EXAMPLE				'x'
+#define HCX_VERSION				'v'
 
 #define ERROR_MAX		100
 #define WATCHDOG		600
@@ -70,6 +75,7 @@
 #define FILTERLIST_MAX		256
 #define	FILTERLIST_LINE_LEN	256
 #define BEACONEXTLIST_MAX	256
+#define FDNSECTIMERB		10000000 /* 10msec */
 #define FDNSECTIMER		200000000
 #define FDNSECTXTIMER		500000000
 
@@ -82,9 +88,14 @@
 
 #define OW_M1M2ROGUE_MAX	10
 
-#define SERVERMSG_MAX		2048
-#define MCPORT			60123
-#define SERVERSTATUS_MAX	1024
+#define SERVERMSG_MAX				2048
+#define MCPORT					60123
+#define SERVERMSG_HEAD_SIZE			1
+#define SERVERMSG_TYPE_CONTROL			0x00
+#define SERVERMSG_TYPE_STATUS			0x01
+#define SERVERMSG_TYPE_PCAPNGHEAD		0x02
+#define SERVERMSG_TYPE_PCAPNG			0x03
+#define SERVERMSG_CONTROL_SENDPCAPNGHEAD	0x01
 
 #define DEBUGMSG_MAX		1024
 #define STATUSMSG_MAX		1024
@@ -94,6 +105,8 @@
 
 #define USER_EXIT_TOT		2
 #define STAYTIME		4
+#define LEDFLASHINTERVAL	5
+
 #define NMEA_MAX		256
 
 #define ESSID_LEN_MAX		32
@@ -143,6 +156,8 @@
 
 #define FM_PROTECT		1
 #define FI_ATTACK		2
+#define FI_VENDOR		3
+#define FI_MAC			6
 
 #define PACKET_RESEND_COUNT_MAX 	7
 #define PACKET_RESEND_TIMER_USEC	15500
